# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/widget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.monitoring.v3 import text_widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_text__widget__pb2
from yandex.cloud.monitoring.v3 import title_widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_title__widget__pb2
from yandex.cloud.monitoring.v3 import chart_widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_chart__widget__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/widget.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'yandex/cloud/monitoring/v3/widget.proto\x12\x1ayandex.cloud.monitoring.v3\x1a,yandex/cloud/monitoring/v3/text_widget.proto\x1a-yandex/cloud/monitoring/v3/title_widget.proto\x1a-yandex/cloud/monitoring/v3/chart_widget.proto\"\xc1\x02\n\x06Widget\x12\x43\n\x08position\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.monitoring.v3.Widget.LayoutPosition\x12\x36\n\x04text\x18\x02 \x01(\x0b\x32&.yandex.cloud.monitoring.v3.TextWidgetH\x00\x12\x38\n\x05title\x18\x03 \x01(\x0b\x32\'.yandex.cloud.monitoring.v3.TitleWidgetH\x00\x12\x38\n\x05\x63hart\x18\x05 \x01(\x0b\x32\'.yandex.cloud.monitoring.v3.ChartWidgetH\x00\x1a<\n\x0eLayoutPosition\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03\x12\t\n\x01w\x18\x03 \x01(\x03\x12\t\n\x01h\x18\x04 \x01(\x03\x42\x08\n\x06widgetBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_monitoring_dot_v3_dot_text__widget__pb2.DESCRIPTOR,yandex_dot_cloud_dot_monitoring_dot_v3_dot_title__widget__pb2.DESCRIPTOR,yandex_dot_cloud_dot_monitoring_dot_v3_dot_chart__widget__pb2.DESCRIPTOR,])




_WIDGET_LAYOUTPOSITION = _descriptor.Descriptor(
  name='LayoutPosition',
  full_name='yandex.cloud.monitoring.v3.Widget.LayoutPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='yandex.cloud.monitoring.v3.Widget.LayoutPosition.x', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='yandex.cloud.monitoring.v3.Widget.LayoutPosition.y', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='yandex.cloud.monitoring.v3.Widget.LayoutPosition.w', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='h', full_name='yandex.cloud.monitoring.v3.Widget.LayoutPosition.h', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=523,
)

_WIDGET = _descriptor.Descriptor(
  name='Widget',
  full_name='yandex.cloud.monitoring.v3.Widget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='yandex.cloud.monitoring.v3.Widget.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='yandex.cloud.monitoring.v3.Widget.text', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.monitoring.v3.Widget.title', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart', full_name='yandex.cloud.monitoring.v3.Widget.chart', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WIDGET_LAYOUTPOSITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='widget', full_name='yandex.cloud.monitoring.v3.Widget.widget',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=212,
  serialized_end=533,
)

_WIDGET_LAYOUTPOSITION.containing_type = _WIDGET
_WIDGET.fields_by_name['position'].message_type = _WIDGET_LAYOUTPOSITION
_WIDGET.fields_by_name['text'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_text__widget__pb2._TEXTWIDGET
_WIDGET.fields_by_name['title'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_title__widget__pb2._TITLEWIDGET
_WIDGET.fields_by_name['chart'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_chart__widget__pb2._CHARTWIDGET
_WIDGET.oneofs_by_name['widget'].fields.append(
  _WIDGET.fields_by_name['text'])
_WIDGET.fields_by_name['text'].containing_oneof = _WIDGET.oneofs_by_name['widget']
_WIDGET.oneofs_by_name['widget'].fields.append(
  _WIDGET.fields_by_name['title'])
_WIDGET.fields_by_name['title'].containing_oneof = _WIDGET.oneofs_by_name['widget']
_WIDGET.oneofs_by_name['widget'].fields.append(
  _WIDGET.fields_by_name['chart'])
_WIDGET.fields_by_name['chart'].containing_oneof = _WIDGET.oneofs_by_name['widget']
DESCRIPTOR.message_types_by_name['Widget'] = _WIDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Widget = _reflection.GeneratedProtocolMessageType('Widget', (_message.Message,), {

  'LayoutPosition' : _reflection.GeneratedProtocolMessageType('LayoutPosition', (_message.Message,), {
    'DESCRIPTOR' : _WIDGET_LAYOUTPOSITION,
    '__module__' : 'yandex.cloud.monitoring.v3.widget_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.Widget.LayoutPosition)
    })
  ,
  'DESCRIPTOR' : _WIDGET,
  '__module__' : 'yandex.cloud.monitoring.v3.widget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.Widget)
  })
_sym_db.RegisterMessage(Widget)
_sym_db.RegisterMessage(Widget.LayoutPosition)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
