# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v2/image_classifier_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.vision.v2 import image_classifier_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/vision/v2/image_classifier_service.proto',
  package='yandex.cloud.ai.vision.v2',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;vision',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8yandex/cloud/ai/vision/v2/image_classifier_service.proto\x12\x19yandex.cloud.ai.vision.v2\x1a\x30yandex/cloud/ai/vision/v2/image_classifier.proto2\x83\x01\n\x16ImageClassifierService\x12i\n\x08\x41nnotate\x12,.yandex.cloud.ai.vision.v2.AnnotationRequest\x1a-.yandex.cloud.ai.vision.v2.AnnotationResponse\"\x00\x42\x65\n\x1dyandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;visionb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_IMAGECLASSIFIERSERVICE = _descriptor.ServiceDescriptor(
  name='ImageClassifierService',
  full_name='yandex.cloud.ai.vision.v2.ImageClassifierService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=138,
  serialized_end=269,
  methods=[
  _descriptor.MethodDescriptor(
    name='Annotate',
    full_name='yandex.cloud.ai.vision.v2.ImageClassifierService.Annotate',
    index=0,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2._ANNOTATIONREQUEST,
    output_type=yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2._ANNOTATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IMAGECLASSIFIERSERVICE)

DESCRIPTOR.services_by_name['ImageClassifierService'] = _IMAGECLASSIFIERSERVICE

# @@protoc_insertion_point(module_scope)
