# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/title_widget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/title_widget.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/monitoring/v3/title_widget.proto\x12\x1ayandex.cloud.monitoring.v3\"\xce\x01\n\x0bTitleWidget\x12\x0c\n\x04text\x18\x01 \x01(\t\x12?\n\x04size\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.monitoring.v3.TitleWidget.TitleSize\"p\n\tTitleSize\x12\x1a\n\x16TITLE_SIZE_UNSPECIFIED\x10\x00\x12\x11\n\rTITLE_SIZE_XS\x10\x01\x12\x10\n\x0cTITLE_SIZE_S\x10\x02\x12\x10\n\x0cTITLE_SIZE_M\x10\x03\x12\x10\n\x0cTITLE_SIZE_L\x10\x04\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
)



_TITLEWIDGET_TITLESIZE = _descriptor.EnumDescriptor(
  name='TitleSize',
  full_name='yandex.cloud.monitoring.v3.TitleWidget.TitleSize',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_XS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_S', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_M', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_L', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=172,
  serialized_end=284,
)
_sym_db.RegisterEnumDescriptor(_TITLEWIDGET_TITLESIZE)


_TITLEWIDGET = _descriptor.Descriptor(
  name='TitleWidget',
  full_name='yandex.cloud.monitoring.v3.TitleWidget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='yandex.cloud.monitoring.v3.TitleWidget.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.monitoring.v3.TitleWidget.size', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TITLEWIDGET_TITLESIZE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=284,
)

_TITLEWIDGET.fields_by_name['size'].enum_type = _TITLEWIDGET_TITLESIZE
_TITLEWIDGET_TITLESIZE.containing_type = _TITLEWIDGET
DESCRIPTOR.message_types_by_name['TitleWidget'] = _TITLEWIDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TitleWidget = _reflection.GeneratedProtocolMessageType('TitleWidget', (_message.Message,), {
  'DESCRIPTOR' : _TITLEWIDGET,
  '__module__' : 'yandex.cloud.monitoring.v3.title_widget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.TitleWidget)
  })
_sym_db.RegisterMessage(TitleWidget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
