# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/extension_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import extension_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/elasticsearch/v1/extension_service.proto',
  package='yandex.cloud.mdb.elasticsearch.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9yandex/cloud/mdb/elasticsearch/v1/extension_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x31yandex/cloud/mdb/elasticsearch/v1/extension.proto\x1a&yandex/cloud/operation/operation.proto\"S\n\x13GetExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"w\n\x15ListExtensionsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n\x16ListExtensionsResponse\x12@\n\nextensions\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.Extension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"V\n\x16\x44\x65leteExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x17\x44\x65leteExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"f\n\x16UpdateExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\"W\n\x17UpdateExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"{\n\x16\x43reateExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x11\n\x03uri\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08\x64isabled\x18\x04 \x01(\x08\"W\n\x17\x43reateExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xc5\x08\n\x10\x45xtensionService\x12\xbe\x01\n\x03Get\x12\x36.yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest\x1a,.yandex.cloud.mdb.elasticsearch.v1.Extension\"Q\x82\xd3\xe4\x93\x02K\x12I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}\x12\xbf\x01\n\x04List\x12\x38.yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest\x1a\x39.yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/managed-elasticsearch/v1/clusters/{cluster_id}/extensions\x12\xd5\x01\n\x06\x43reate\x12\x39.yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02?\":/managed-elasticsearch/v1/clusters/{cluster_id}/extensions:\x01*\xb2\xd2*$\n\x17\x43reateExtensionMetadata\x12\tExtension\x12\xe4\x01\n\x06Update\x12\x39.yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest\x1a!.yandex.cloud.operation.Operation\"|\x82\xd3\xe4\x93\x02N2I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}:\x01*\xb2\xd2*$\n\x17UpdateExtensionMetadata\x12\tExtension\x12\xee\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\x82\xd3\xe4\x93\x02K*I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}\xb2\xd2*0\n\x17\x44\x65leteExtensionMetadata\x12\x15google.protobuf.EmptyB|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,])




_GETEXTENSIONREQUEST = _descriptor.Descriptor(
  name='GetExtensionRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=365,
)


_LISTEXTENSIONSREQUEST = _descriptor.Descriptor(
  name='ListExtensionsRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=486,
)


_LISTEXTENSIONSRESPONSE = _descriptor.Descriptor(
  name='ListExtensionsResponse',
  full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extensions', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse.extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=603,
)


_DELETEEXTENSIONREQUEST = _descriptor.Descriptor(
  name='DeleteExtensionRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=691,
)


_DELETEEXTENSIONMETADATA = _descriptor.Descriptor(
  name='DeleteExtensionMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionMetadata.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=780,
)


_UPDATEEXTENSIONREQUEST = _descriptor.Descriptor(
  name='UpdateExtensionRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest.active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=884,
)


_UPDATEEXTENSIONMETADATA = _descriptor.Descriptor(
  name='UpdateExtensionMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionMetadata.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=886,
  serialized_end=973,
)


_CREATEEXTENSIONREQUEST = _descriptor.Descriptor(
  name='CreateExtensionRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest.disabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1098,
)


_CREATEEXTENSIONMETADATA = _descriptor.Descriptor(
  name='CreateExtensionMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionMetadata.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1100,
  serialized_end=1187,
)

_LISTEXTENSIONSRESPONSE.fields_by_name['extensions'].message_type = yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2._EXTENSION
DESCRIPTOR.message_types_by_name['GetExtensionRequest'] = _GETEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name['ListExtensionsRequest'] = _LISTEXTENSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListExtensionsResponse'] = _LISTEXTENSIONSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteExtensionRequest'] = _DELETEEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteExtensionMetadata'] = _DELETEEXTENSIONMETADATA
DESCRIPTOR.message_types_by_name['UpdateExtensionRequest'] = _UPDATEEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateExtensionMetadata'] = _UPDATEEXTENSIONMETADATA
DESCRIPTOR.message_types_by_name['CreateExtensionRequest'] = _CREATEEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateExtensionMetadata'] = _CREATEEXTENSIONMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetExtensionRequest = _reflection.GeneratedProtocolMessageType('GetExtensionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTENSIONREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest)
  })
_sym_db.RegisterMessage(GetExtensionRequest)

ListExtensionsRequest = _reflection.GeneratedProtocolMessageType('ListExtensionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXTENSIONSREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest)
  })
_sym_db.RegisterMessage(ListExtensionsRequest)

ListExtensionsResponse = _reflection.GeneratedProtocolMessageType('ListExtensionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXTENSIONSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse)
  })
_sym_db.RegisterMessage(ListExtensionsResponse)

DeleteExtensionRequest = _reflection.GeneratedProtocolMessageType('DeleteExtensionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEXTENSIONREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest)
  })
_sym_db.RegisterMessage(DeleteExtensionRequest)

DeleteExtensionMetadata = _reflection.GeneratedProtocolMessageType('DeleteExtensionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEXTENSIONMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionMetadata)
  })
_sym_db.RegisterMessage(DeleteExtensionMetadata)

UpdateExtensionRequest = _reflection.GeneratedProtocolMessageType('UpdateExtensionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXTENSIONREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest)
  })
_sym_db.RegisterMessage(UpdateExtensionRequest)

UpdateExtensionMetadata = _reflection.GeneratedProtocolMessageType('UpdateExtensionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXTENSIONMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionMetadata)
  })
_sym_db.RegisterMessage(UpdateExtensionMetadata)

CreateExtensionRequest = _reflection.GeneratedProtocolMessageType('CreateExtensionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEXTENSIONREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest)
  })
_sym_db.RegisterMessage(CreateExtensionRequest)

CreateExtensionMetadata = _reflection.GeneratedProtocolMessageType('CreateExtensionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEXTENSIONMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.CreateExtensionMetadata)
  })
_sym_db.RegisterMessage(CreateExtensionMetadata)


DESCRIPTOR._options = None
_GETEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
_GETEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
_LISTEXTENSIONSREQUEST.fields_by_name['cluster_id']._options = None
_LISTEXTENSIONSREQUEST.fields_by_name['page_size']._options = None
_LISTEXTENSIONSREQUEST.fields_by_name['page_token']._options = None
_DELETEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
_DELETEEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
_DELETEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
_DELETEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None
_UPDATEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
_UPDATEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
_UPDATEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None
_CREATEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
_CREATEEXTENSIONREQUEST.fields_by_name['name']._options = None
_CREATEEXTENSIONREQUEST.fields_by_name['uri']._options = None
_CREATEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
_CREATEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None

_EXTENSIONSERVICE = _descriptor.ServiceDescriptor(
  name='ExtensionService',
  full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1190,
  serialized_end=2283,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.Get',
    index=0,
    containing_service=None,
    input_type=_GETEXTENSIONREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2._EXTENSION,
    serialized_options=b'\202\323\344\223\002K\022I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.List',
    index=1,
    containing_service=None,
    input_type=_LISTEXTENSIONSREQUEST,
    output_type=_LISTEXTENSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/managed-elasticsearch/v1/clusters/{cluster_id}/extensions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEEXTENSIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?\":/managed-elasticsearch/v1/clusters/{cluster_id}/extensions:\001*\262\322*$\n\027CreateExtensionMetadata\022\tExtension',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEEXTENSIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002N2I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}:\001*\262\322*$\n\027UpdateExtensionMetadata\022\tExtension',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEEXTENSIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002K*I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}\262\322*0\n\027DeleteExtensionMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTENSIONSERVICE)

DESCRIPTOR.services_by_name['ExtensionService'] = _EXTENSIONSERVICE

# @@protoc_insertion_point(module_scope)
