# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/downsampling.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/downsampling.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/monitoring/v3/downsampling.proto\x12\x1ayandex.cloud.monitoring.v3\"\xbd\x04\n\x0c\x44ownsampling\x12\x14\n\nmax_points\x18\x01 \x01(\x03H\x00\x12\x17\n\rgrid_interval\x18\x02 \x01(\x03H\x00\x12\x12\n\x08\x64isabled\x18\x03 \x01(\x08H\x00\x12R\n\x10grid_aggregation\x18\x04 \x01(\x0e\x32\x38.yandex.cloud.monitoring.v3.Downsampling.GridAggregation\x12H\n\x0bgap_filling\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.monitoring.v3.Downsampling.GapFilling\"\xd2\x01\n\x0fGridAggregation\x12 \n\x1cGRID_AGGREGATION_UNSPECIFIED\x10\x00\x12\x18\n\x14GRID_AGGREGATION_MAX\x10\x01\x12\x18\n\x14GRID_AGGREGATION_MIN\x10\x02\x12\x18\n\x14GRID_AGGREGATION_SUM\x10\x03\x12\x18\n\x14GRID_AGGREGATION_AVG\x10\x04\x12\x19\n\x15GRID_AGGREGATION_LAST\x10\x05\x12\x1a\n\x16GRID_AGGREGATION_COUNT\x10\x06\"o\n\nGapFilling\x12\x1b\n\x17GAP_FILLING_UNSPECIFIED\x10\x00\x12\x14\n\x10GAP_FILLING_NULL\x10\x01\x12\x14\n\x10GAP_FILLING_NONE\x10\x02\x12\x18\n\x14GAP_FILLING_PREVIOUS\x10\x03\x42\x06\n\x04modeBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
)



_DOWNSAMPLING_GRIDAGGREGATION = _descriptor.EnumDescriptor(
  name='GridAggregation',
  full_name='yandex.cloud.monitoring.v3.Downsampling.GridAggregation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_MAX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_MIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_SUM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_AVG', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_LAST', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_COUNT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=320,
  serialized_end=530,
)
_sym_db.RegisterEnumDescriptor(_DOWNSAMPLING_GRIDAGGREGATION)

_DOWNSAMPLING_GAPFILLING = _descriptor.EnumDescriptor(
  name='GapFilling',
  full_name='yandex.cloud.monitoring.v3.Downsampling.GapFilling',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GAP_FILLING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAP_FILLING_NULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAP_FILLING_NONE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAP_FILLING_PREVIOUS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=532,
  serialized_end=643,
)
_sym_db.RegisterEnumDescriptor(_DOWNSAMPLING_GAPFILLING)


_DOWNSAMPLING = _descriptor.Descriptor(
  name='Downsampling',
  full_name='yandex.cloud.monitoring.v3.Downsampling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_points', full_name='yandex.cloud.monitoring.v3.Downsampling.max_points', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_interval', full_name='yandex.cloud.monitoring.v3.Downsampling.grid_interval', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.monitoring.v3.Downsampling.disabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_aggregation', full_name='yandex.cloud.monitoring.v3.Downsampling.grid_aggregation', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gap_filling', full_name='yandex.cloud.monitoring.v3.Downsampling.gap_filling', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DOWNSAMPLING_GRIDAGGREGATION,
    _DOWNSAMPLING_GAPFILLING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mode', full_name='yandex.cloud.monitoring.v3.Downsampling.mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=78,
  serialized_end=651,
)

_DOWNSAMPLING.fields_by_name['grid_aggregation'].enum_type = _DOWNSAMPLING_GRIDAGGREGATION
_DOWNSAMPLING.fields_by_name['gap_filling'].enum_type = _DOWNSAMPLING_GAPFILLING
_DOWNSAMPLING_GRIDAGGREGATION.containing_type = _DOWNSAMPLING
_DOWNSAMPLING_GAPFILLING.containing_type = _DOWNSAMPLING
_DOWNSAMPLING.oneofs_by_name['mode'].fields.append(
  _DOWNSAMPLING.fields_by_name['max_points'])
_DOWNSAMPLING.fields_by_name['max_points'].containing_oneof = _DOWNSAMPLING.oneofs_by_name['mode']
_DOWNSAMPLING.oneofs_by_name['mode'].fields.append(
  _DOWNSAMPLING.fields_by_name['grid_interval'])
_DOWNSAMPLING.fields_by_name['grid_interval'].containing_oneof = _DOWNSAMPLING.oneofs_by_name['mode']
_DOWNSAMPLING.oneofs_by_name['mode'].fields.append(
  _DOWNSAMPLING.fields_by_name['disabled'])
_DOWNSAMPLING.fields_by_name['disabled'].containing_oneof = _DOWNSAMPLING.oneofs_by_name['mode']
DESCRIPTOR.message_types_by_name['Downsampling'] = _DOWNSAMPLING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Downsampling = _reflection.GeneratedProtocolMessageType('Downsampling', (_message.Message,), {
  'DESCRIPTOR' : _DOWNSAMPLING,
  '__module__' : 'yandex.cloud.monitoring.v3.downsampling_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.Downsampling)
  })
_sym_db.RegisterMessage(Downsampling)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
